@@ -5,8 +5,6 @@ import (
 	"context"
 	"time"
 
-	"github.com/xtls/xray-core/transport/internet/stat"
-
 	"github.com/xtls/xray-core/common"
 	"github.com/xtls/xray-core/common/buf"
 	"github.com/xtls/xray-core/common/crypto"
@@ -18,17 +16,16 @@ import (
 	"github.com/xtls/xray-core/core"
 	"github.com/xtls/xray-core/features/policy"
 	"github.com/xtls/xray-core/features/routing"
+	"github.com/xtls/xray-core/transport/internet/stat"
 )
 
-var (
-	dcList = []net.Address{
-		net.ParseAddress("149.154.175.50"),
-		net.ParseAddress("149.154.167.51"),
-		net.ParseAddress("149.154.175.100"),
-		net.ParseAddress("149.154.167.91"),
-		net.ParseAddress("149.154.171.5"),
-	}
-)
+var dcList = []net.Address{
+	net.ParseAddress("149.154.175.50"),
+	net.ParseAddress("149.154.167.51"),
+	net.ParseAddress("149.154.175.100"),
+	net.ParseAddress("149.154.167.91"),
+	net.ParseAddress("149.154.171.5"),
+}
 
 type Server struct {
 	user    *protocol.User
@@ -64,8 +61,10 @@ func (s *Server) Network() []net.Network {
 	return []net.Network{net.Network_TCP}
 }
 
-var ctype1 = []byte{0xef, 0xef, 0xef, 0xef}
-var ctype2 = []byte{0xee, 0xee, 0xee, 0xee}
+var (
+	ctype1 = []byte{0xef, 0xef, 0xef, 0xef}
+	ctype2 = []byte{0xee, 0xee, 0xee, 0xee}
+)
 
 func isValidConnectionType(c [4]byte) bool {
 	if bytes.Equal(c[:], ctype1) {
@@ -144,7 +143,7 @@ func (s *Server) Process(ctx context.Context, network net.Network, conn stat.Con
 		return buf.Copy(link.Reader, writer, buf.UpdateActivity(timer))
 	}
 
-	var responseDoneAndCloseWriter = task.OnSuccess(response, task.Close(link.Writer))
+	responseDoneAndCloseWriter := task.OnSuccess(response, task.Close(link.Writer))
 	if err := task.Run(ctx, request, responseDoneAndCloseWriter); err != nil {
 		common.Interrupt(link.Reader)
 		common.Interrupt(link.Writer)
